package pausenuhr.model;

import java.time.LocalTime;

public class ZustandBestimmen {

    /**
     * Bestimmt anhand der übergebenen Uhrzeit den Zustand ob es sich um Unterricht, Pause oder Freizeit handelt
     * für normale Wochen mit einer Unterrichtszeit von 8:30 - 15:35
     *
     * @param zeit Zeit zu der der Zustand zurückgegeben werden soll
     * @return Der zu der übergebenen Zeit passende Zustand aus der Klasse "Zustand"
     */
    public static Zustand aktuellerZustandNormal(LocalTime zeit) {

        if (zeit.isAfter(LocalTime.of(8, 29, 59, 999999)) && zeit.isBefore(LocalTime.of(15, 35))) {
            // Hiermit ist sichergestellt, dass sich die übergebene Zeit zwischen 8:30 und 15:35 befindet

            if (zeit.isBefore(LocalTime.of(10,00))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(10,15))) {
                return Zustand.PAUSE;
            } else if (zeit.isBefore(LocalTime.of(11,45))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(11,50))) {
                return Zustand.PAUSE;
            } else if (zeit.isBefore(LocalTime.of(12,35))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(13,15))) {
                return Zustand.PAUSE;
            } else if (zeit.isBefore(LocalTime.of(14,45))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(14,50))) {
                return Zustand.PAUSE;
            } else {
                return Zustand.UNTERRICHT;
            }

        } else {
            return Zustand.FREIZEIT;
        }
    }

    /**
     * Bestimmt anhand der übergebenen Uhrzeit den Zustand ob es sich um Unterricht, Pause oder Freizeit handelt
     * für lange Wochen mit einer Unterrichtszeit von 8:30 - 17:10
     *
     * @param zeit Zeit zu der der Zustand zurückgegeben werden soll
     * @return Der zu der übergebenen Zeit passende Zustand aus der Klasse "Zustand"
     */
    public static Zustand aktuellerZustandLang(LocalTime zeit) {

        if (zeit.isAfter(LocalTime.of(8, 29, 59, 999999)) && zeit.isBefore(LocalTime.of(17, 10))) {
            // Hiermit ist sichergestellt, dass sich die übergebene Zeit zwischen 8:30 und 17:10 befindet

            if (zeit.isBefore(LocalTime.of(10,00))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(10,15))) {
                return Zustand.PAUSE;
            } else if (zeit.isBefore(LocalTime.of(11,45))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(11,50))) {
                return Zustand.PAUSE;
            } else if (zeit.isBefore(LocalTime.of(12,35))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(13,15))) {
                return Zustand.PAUSE;
            } else if (zeit.isBefore(LocalTime.of(14,45))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(14,50))) {
                return Zustand.PAUSE;
            } else if (zeit.isBefore(LocalTime.of(16,20))) {
                return Zustand.UNTERRICHT;
            } else if (zeit.isBefore(LocalTime.of(16,25))) {
                return Zustand.PAUSE;
            } else {
                return Zustand.UNTERRICHT;
            }

        } else {
            return Zustand.FREIZEIT;
        }
    }

    /**
     * Bestimmt anhand der übergebenen Uhrzeit die Dauer bis zum nächsten Zustandswechsel
     * für normale Wochen mit einer Unterrichtszeit von 8:30 - 15:35
     *
     * @param zeit Zeit zu der die Endzeit ermittelt werden soll
     * @return Die zu der übergebenen Zeit passende Endzeit
     */
    public static LocalTime aktuellerZustandNormalBis(LocalTime zeit) {
        if (zeit.isBefore(LocalTime.of(8,30))) {
            return LocalTime.of(8, 30);
        } else if (zeit.isBefore(LocalTime.of(10,00))) {
            return LocalTime.of(10, 00);
        } else if (zeit.isBefore(LocalTime.of(10,15))) {
            return LocalTime.of(10, 15);
        } else if (zeit.isBefore(LocalTime.of(11,45))) {
            return LocalTime.of(11, 45);
        } else if (zeit.isBefore(LocalTime.of(11,50))) {
            return LocalTime.of(11, 50);
        } else if (zeit.isBefore(LocalTime.of(12,35))) {
            return LocalTime.of(12, 35);
        } else if (zeit.isBefore(LocalTime.of(13,15))) {
            return LocalTime.of(13, 15);
        } else if (zeit.isBefore(LocalTime.of(14,45))) {
            return LocalTime.of(14, 45);
        } else if (zeit.isBefore(LocalTime.of(14,50))) {
            return LocalTime.of(14, 50);
        }else if (zeit.isBefore(LocalTime.of(15,35))) {
            return LocalTime.of(15, 35);
        } else {
            return LocalTime.of(8, 30);
        }
    }

    /**
     * Bestimmt anhand der übergebenen Uhrzeit die Dauer bis zum nächsten Zustandswechsel
     * für lange Wochen mit einer Unterrichtszeit von 8:30 - 17:10
     *
     * @param zeit Zeit zu der die Endzeit ermittelt werden soll
     * @return Die zu der übergebenen Zeit passende Endzeit
     */
    public static LocalTime aktuellerZustandLangBis(LocalTime zeit) {
        if (zeit.isBefore(LocalTime.of(8,30))) {
            return LocalTime.of(8, 30);
        } else if (zeit.isBefore(LocalTime.of(10,00))) {
            return LocalTime.of(10, 00);
        } else if (zeit.isBefore(LocalTime.of(10,15))) {
            return LocalTime.of(10, 15);
        } else if (zeit.isBefore(LocalTime.of(11,45))) {
            return LocalTime.of(11, 45);
        } else if (zeit.isBefore(LocalTime.of(11,50))) {
            return LocalTime.of(11, 50);
        } else if (zeit.isBefore(LocalTime.of(12,35))) {
            return LocalTime.of(12, 35);
        } else if (zeit.isBefore(LocalTime.of(13,15))) {
            return LocalTime.of(13, 15);
        } else if (zeit.isBefore(LocalTime.of(14,45))) {
            return LocalTime.of(14, 45);
        } else if (zeit.isBefore(LocalTime.of(14,50))) {
            return LocalTime.of(14, 50);
        } else if (zeit.isBefore(LocalTime.of(16,20))) {
            return LocalTime.of(16, 20);
        }  else if (zeit.isBefore(LocalTime.of(16,25))) {
            return LocalTime.of(16, 25);
        } else if (zeit.isBefore(LocalTime.of(17,10))) {
            return LocalTime.of(17, 10);
        }else {
            return LocalTime.of(8, 30);
        }
    }
}
